@@ -8,13 +8,14 @@ import sys
 import time
 from pathlib import Path
 
+import appdirs
 import filetype  # type: ignore
 import cloudscraper  # type: ignore
 
 user_agent = {"User-Agent": "git.io/wanda"}
 content_json = "application/json"
-folder = f"{str(Path.home())}/wanda"
-version = "0.60.3"
+folder = appdirs.user_cache_dir("wanda")
+version = "0.60.5"
 
 
 def is_connected():
@@ -111,6 +112,12 @@ def get(url):
     return response
 
 
+def program_exists(program):
+    return subprocess.call(
+        ['which', program], stdout=subprocess.DEVNULL, stderr=subprocess.DEVNULL,
+    ) == 0
+
+
 def set_wp_win(path):
     import ctypes
 
@@ -118,17 +125,22 @@ def set_wp_win(path):
 
 
 def set_wp_linux(path):
-    if os.environ.get("SWAYSOCK"):
+    if not os.environ.get("DESKTOP_SESSION"):
+        setter = "feh --bg-scale"
+    elif os.environ.get("SWAYSOCK"):
         setter = "eval ogurictl output '*' --image"
     elif os.environ.get("DESKTOP_SESSION").lower == "mate":
         setter = "gsettings set org.mate.background picture-filename"
     elif contains(
             os.environ.get("DESKTOP_SESSION").lower(), False, ["xfce", "xubuntu"]
     ):
-        setter = (
-            "xfconf-query --channel xfce4-desktop --property /backdrop/screen0/monitor0/workspace0/last-image "
-            "--set "
-        )
+        if program_exists("xfce4-set-wallpaper"):
+            setter = "xfce4-set-wallpaper"
+        else:
+            setter = (
+                "xfconf-query --channel xfce4-desktop --property /backdrop/screen0/monitor0/last-image "
+                "--set "
+            )
     elif os.environ.get("DESKTOP_SESSION").lower() == "lxde":
         setter = "pcmanfm --set-wallpaper"
     elif contains(
